/*
 * gui.h - the gui for createrec-gtk
 * Copyright (c) 2009 Markus Kohm
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef __gui_h
#define __gui_h

#include <glib.h>

#ifndef VERSION
#define VERSION "0.1-unknown"
#endif

typedef struct _gui_context GuiContext;

/**
 * Show progress or state of the programm
 *
 * @param progress < 0 for not changing the progress, 
 *                 0.0..1.0 for changing progress.
 * @param message is a state string or NULL if state not changed
 * @param gui_context pointer to a gui context.
 */
void gui_show_state( gdouble progress, gchar *message,
		     GuiContext *gui_context );
 
/**
 * Do all initialization for the gui without entering the main loop.
 *
 * Note, that argc and argv are input and output parameters.  After
 * the initialization all gui parameters are removed from the array.
 *
 * @param argc pointer to number of arguments
 * @param argv array of arguments
 * @param gui_context pointer to a gui context.
 * @return TRUE if ok, FALSE on error
 */
gboolean gui_init(int *argc, char ***argv, GuiContext **gui_context);

/**
 * Do the main gui loop.
 *
 * @param gui_context pointer to a gui context.
 * @return TRUE if ok, FALSE on error
 */
gboolean gui_do(GuiContext *gui_context);

/**
 * Exit the gui
 *
 * Note, that gui_context is not longer valid after this call!
 *
 * @param gui_context pointer to a gui context.
 * @return TRUE if exit, FALSE if not
 */
gboolean gui_exit(GuiContext *gui_context);

/**
 * Spawn a process, show the output of the process and wait for termination
 *
 * Note: errors are not shown in the given gui context but reported via err!
 *
 * @param command The command to be executed
 * @param gui_context pointer to a gui context.
 * @param err the error context to be used
 * @return TRUE if everything was fine, FALSE on error
 */
gboolean gui_spawn_sync(const gchar *command, 
			GuiContext *gui_context, 
			GError **err );
 
#endif /* __gui_h */
