/*
 * metanalyze
 * Copyright (c) 2009 Markus Kohm
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include <sys/types.h>

int main(int argc, char **argv) {
    const char *filename;
    const char *dayname[7] = { "sun", "mon", "tue", "wed", "thu", "fri", "sat" };
    u_int8_t b[112];
    char title[62];
    FILE *in;

    if ( argc != 2 ) {
	fprintf( stderr, "%s: argument expected\n"
		 "Usage: %s meta.dat\n",
		 argv[0], argv[0] );
	exit(1);
    }

    filename = argv[1];
    if ( ( in = fopen( filename, "rb" ) ) == NULL ) {
	perror( filename );
	exit (1);
    }

    if ( fread( b, sizeof( u_int8_t ), 112, in ) != 112 ) {
	perror( filename );
	fclose( in );
	exit(1);
    }

    if ( fgetc( in ) != EOF || ! feof( in ) ) {
	fprintf( stderr, 
		"%s: is not a valid meta.dat (file size != 112 Bytes)\n",
		filename );
	fclose( in );
	exit(1);
    }

    fclose(in );

    strncpy( title, b+0x0d, 62 );
    title[61] = 0;

    fprintf( stdout,
	     "%s:\n"
	     "  header:        0x%02x 0x%02x 0x%02x 0x%02x 0x%02x (expected: 0x05 0x00 0x72 0x6a 0x07)\n"
	     "  reserved:      0x%02x 0x%02x 0x%02x 0x%02x 0x%02x 0x%02x 0x%02x (expected: 7 * 0x00)\n"
	     "  type of title: 0x%02x = %s\n"
	     "  title:         \"%s\"\n"
	     "  start time:    %02u:%02u:%02u %s %04u-%02u-%02u\n"
	     "  reserved:      0x%04x (expected: 0x0000)\n"
	     "  reserved:      0x%02x 0x%02x 0x%02x (expected: 3 * 0x00)\n"
	     "  info packets:  0x%08lx = %lu\n"
	     "  duration:      %02u:%02u:%02u\n"
	     "  reserved:      %02u (expected: 0x00)\n"
	     "  service:       0x%02x = %s\n"
	     "  reserved:      0x%02x 0x%02x 0x%02x (expected: 3 * 0x00)\n"
	     "  fixed 01:      0x%02x (expected: 0x01)\n"
	     "  reserved:      0x%02x 0x%02x 0x%02x (expected: 3 * 0x00)\n"
	     "  programm id:   0x%04x\n"
	     "  reserved:      0x%02x 0x%02x (expected: 2 * 0x00)\n"
	     "  timer number:  0x%08lx\n"
	     , 
	     filename,
	     b[0], b[1], b[2], b[3], b[4],
	     b[5], b[6], b[7], b[8], b[9], b[0xa], b[0xb],
	     b[0xc], ( b[0xc] == 8 ) ? "transmission" : ( b[0xc] == 2 ) ? "station/manual input" : "unkown",
	     title,
	     b[0x4b], b[0x4c], b[0x4d], ( b[0x54] < 7 ) ? dayname[b[0x54]] : "???",
	     b[0x50] | ( (unsigned int)(b[0x51]) << 8 ), b[0x52], b[0x53],
	     b[0x4e] | ( (unsigned int)(b[0x4f]) << 8 ),
	     b[0x55], b[0x56], b[0x57],
	     b[0x58] | ( (unsigned long)(b[0x59]) << 8)
	     | ( (unsigned long)(b[0x5a]) << 16) 
	     | ( (unsigned long)(b[0x5b]) << 24),
	     b[0x58] | ( (unsigned long)(b[0x59]) << 8)
	     | ( (unsigned long)(b[0x5a]) << 16) 
	     | ( (unsigned long)(b[0x5b]) << 24),
	     b[0x5c], b[0x5d], b[0x5e],
	     b[0x5f],
	     b[0x60], ( b[0x60] == 0 ) ? "TV" : ( b[0x60] == 1 ) ? "Radio" : "Unknown",
	     b[0x61], b[0x62], b[0x63],
	     b[0x64],
	     b[0x65], b[0x66], b[0x67],
	     b[0x68] | (unsigned int)(b[0x69] << 8),
	     b[0x6a], b[0x6b],
	     b[0x6c] | ( (unsigned long)(b[0x6d]) << 8)
	     | ( (unsigned long)(b[0x6e]) << 16) 
	     | ( (unsigned long)(b[0x6f]) << 24)
	);

    return 0;
} 
