/*
 * rec.h - the ifile for createrec-gtk
 * Copyright (c) 2009 Markus Kohm
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef __rec_h
#define __rec_h

#include <glib.h>
#include "gui.h"

#define CR_STREAM_ERROR g_quark_from_static_string( "CREATEREC::STREAM::ERROR" )
typedef enum {
    CR_STREAM_ERROR_UNKOWN,    /* simply not an error */
    CR_STREAM_ERROR_TIDPID,    /* Table ID error */
    CR_STREAM_ERROR_TABNVLD    /* Table not valid */
} CRPacketError;


/**
 * create new ts files from ifile
 *
 * Note: creating the ts will change the iF_context!
 *
 * @param dstdir The folder where to create the ts files.
 * @param iF_context pointer to the ifile context of the source
 * @param gui_context a gui context to report
 * @param err Will be set on error, to describe the error, if not NULL.
 * @return TRUE on success, FALSE on error
 */
gboolean rec_create_ts(const gchar *dstdir,
		       IFileContext *iF_context,
		       GuiContext *gui_context,
		       GError **err);

/**
 * create new meta.dat from ifile
 *
 * Note: you have to call rec_create_ts before to set up iF_context!
 *
 * @param dstdir The folder where to create the meta.dat.
 * @param iF_context pointer to the ifile context of the source
 * @param gui_context a gui context to report
 * @param err Will be set on error, to describe the error, if not NULL.
 * @return TRUE on success, FALSE on error
 */
gboolean rec_create_meta(const gchar *dstdir,
			 IFileContext *iF_context,
			 GuiContext *gui_context,
			 GError **err);

/**
 * create new rec.cp files from ifile
 *
 * Note: creating the ts will change the iF_context!
 *
 * @param dstdir The folder where to create the file.
 * @param iF_context pointer to the ifile context of the source
 * @param gui_context a gui context to report
 * @param err Will be set on error, to describe the error, if not NULL.
 * @return TRUE on success, FALSE on error
 */
gboolean rec_create_cp(const gchar *dstdir,
		       IFileContext *iF_context,
		       GuiContext *gui_context,
		       GError **err);

/**
 * create new rec.bm files from ifile
 *
 * Note: creating the ts will change the iF_context!
 *
 * @param dstdir The folder where to create the file.
 * @param iF_context pointer to the ifile context of the source
 * @param gui_context a gui context to report
 * @param err Will be set on error, to describe the error, if not NULL.
 * @return TRUE on success, FALSE on error
 */
gboolean rec_create_bm(const gchar *dstdir,
		       IFileContext *iF_context,
		       GuiContext *gui_context,
		       GError **err);

#endif /* __rec_h */
